#!/bin/bash

if [ -z "$GISBASE" ] ; then
    echo "ERROR: You must be in GRASS GIS to run this program." 1>&2
    exit 1
fi

if [ -z "$R_BIN" ]; then
	ENVFILE=`dirname $0`/landsat_setenv.txt
	echo $ENVFILE
	if [ ! -e $ENVFILE ]; then
		g.message -e "ERROR: landsat_setenv.txt was not found. You must put landsat_setenv.txt in the same directory as this script."
		exit 1
	fi
	source $ENVFILE
fi


mkdir temp
for F in `ls *.tar.gz 2>/dev/null`; do

	tar xvfz $F -C temp
	cd temp
	LIST=`ls *.TIF 2> /dev/null`

	for i in $LIST; do

		SUFFIX=`basename $i ".TIF" | cut -d '_' -f 2`
		if [ $SUFFIX = 'B8' ]; then
			continue
		fi

		gdalwarp -of "GTiff" -r lanczos -t_srs "`g.proj -j -f`" $i "temp.tif"
		if [ $? -ne 0 ]; then
			exit 1
		fi
		OUTPUTNAME=`basename $i ".TIF"`
		echo $i $OUTPUTNAME
		r.in.gdal input="temp.tif" output=$OUTPUTNAME
		if [ $? -ne 0 ]; then
			exit 1
		fi
		r.colors map=$OUTPUTNAME color=grey
		rm -f "temp.tif"

	done

	cd ..
	rm -f temp/*

done

rm -r -f temp

#
# set region to imported raster map.
#
g.region rast=`g.mlist type=rast | head -n 1`
