#!/bin/bash

if [ $# != 1 ]; then
	echo "modis_calc_index.sh usage: [target year]"
	exit 1
fi

if [ -z "$GISBASE" ] ; then
    echo "ERROR: You must be in GRASS GIS to run this program." 1>&2
    exit 1
fi

if [ -z "$R_BIN" ]; then
	ENVFILE=`dirname $0`/modis_setenv.txt
	echo $ENVFILE
	if [ ! -e $ENVFILE ]; then
		g.message -e "modis_setenv.txt was not found. You must put modis_setenv.txt in the same directory as this script."
		exit 1
	fi
	source $ENVFILE
fi

YEAR=$1
if [ `g.mlist pattern="interp_${PRODUCT_NAME}.A${YEAR}*_band2" | wc -l` -eq 0 ]; then
	g.message -e "No images of ${YEAR} was found."
	exit 1
fi

for I in `g.mlist pattern="interp_${PRODUCT_NAME}.A${YEAR}*_band2"`; do

	echo `echo $I | cut -d "_" -f 1-2`
	BAND2=$I
	BAND1=`echo $I | cut -d "_" -f 1-2`_band1
	BAND3=`echo $I | cut -d "_" -f 1-2`_band3
	BAND6=`echo $I | cut -d "_" -f 1-2`_band6
	BAND4=`echo $I | cut -d "_" -f 1-2`_band4
	NDVI=`echo $I | cut -d "_" -f 1-2`_ndvi
	NDSI=`echo $I | cut -d "_" -f 1-2`_ndsi
	SI=`echo $I | cut -d "_"  -f 1-2`_si
	r.mapcalc "${NDVI}=(float(${BAND2})-float(${BAND1}))/(float(${BAND2})+float(${BAND1}))"
	if [ $? -ne 0 ]; then
		exit 1
	fi
	r.mapcalc "${NDSI}=(float(${BAND6})-float(${BAND2}))/(float(${BAND6})+float(${BAND2}))"
	if [ $? -ne 0 ]; then
		exit 1
	fi
	r.mapcalc "${SI}=pow((1.0-0.0001*float(${BAND1}))*(1.0-0.0001*float(${BAND4}))*(1.0-0.0001*float(${BAND3})), 0.333333)"
	if [ $? -ne 0 ]; then
		exit 1
	fi

done

