#!/bin/bash

if [ $# != 3 ]; then
	echo "modis_check_accuracy usage: [truth raster layer] [output path] [verify point num]"
	exit 1
fi

if [ -z "$GISBASE" ] ; then
    echo "ERROR: You must be in GRASS GIS to run this program." 1>&2
    exit 1
fi

if [ -z "$R_BIN" ]; then
	ENVFILE=`dirname $0`/modis_setenv.txt
	echo $ENVFILE
	if [ ! -e $ENVFILE ]; then
		g.message -e "modis_setenv.txt was not found. You must put modis_setenv.txt in the same directory as this script."
		exit 1
	fi
	source $ENVFILE
fi

TRUTH_RASTER=$1
OUTPUT_PATH=$2
NUMPOINTS=$3
POINTLAYER_NAME="verify_tc"

eval `g.findfile element=cell file=$TRUTH_RASTER`
if [ ! "$file" ]; then
	g.message -e "Truth raster layer [$TRUTH_RASTER] was not found."
	exit 1
fi

eval `g.findfile element=vector file=${POINTLAYER_NAME}`
if [ "$file" ]; then
	g.remove -f vect=${POINTLAYER_NAME}
	if [ $? -ne 0 ]; then
		g.message -e "failed to remove old point layer. Please remove layer [verify_tc] manually."
		exit 1
	fi
fi


r.random input=result_tree_cover_dep vector_output=${POINTLAYER_NAME} n=${NUMPOINTS}
v.db.addcol map=${POINTLAYER_NAME} column="tc_truth DOUBLE PRECISION"
if [ $? -ne 0 ]; then
	exit 1
fi
v.what.rast vector=${POINTLAYER_NAME} raster=${TRUTH_RASTER} column="tc_truth"

if [ -e $OUTPUT_PATH ]; then
	rm -f $OUTPUT_PATH
fi

db.out.ogr input=${POINTLAYER_NAME} dsn=${OUTPUT_PATH} format=CSV

