#!/bin/bash

if [ -z "$R_BIN" ]; then
	ENVFILE=`dirname $0`/modis_setenv.txt
	echo $ENVFILE
	if [ ! -e $ENVFILE ]; then
		echo "ERROR: modis_setenv.txt was not found. You must put modis_setenv.txt in the same directory as this script."
	fi
	source $ENVFILE
fi

if [ $# != 8 ] && [ $# != 11 ]; then
	echo "modis_download.sh usage: \
 [[options]] [your E-mail address] [product name] [target year] [date from] [date to] [save path]"
	echo "options:"
	echo "  -t tile name(comma separated) if you want to download multiple tiles, specify tile names separated by comma."
	echo "	-r west south east north ( lat-lon )"
	exit 1
fi

if [ $1 = "-t" ]; then
	TILE=$2
	ADDRESS=$3
	PRODUCT=$4
	YEAR=$5
	DATE_FROM=$6
	DATE_TO=$7
	SAVEPATH=$8
elif [ $1 == "-r" ]; then
	WEST=$2
	SOUTH=$3
	EAST=$4
	NORTH=$5
	ADDRESS=$6
	PRODUCT=$7
	YEAR=$8
	DATE_FROM=$9
	shift
	DATE_TO=$9
	shift
	SAVEPATH=$9

	TILE=''
	SEARCHFRAME=`dirname $0`/search_frame.py
	echo $SEARCHFRAME
	FLIST=`python $SEARCHFRAME $WEST $SOUTH $EAST $NORTH`
	for L in $FLIST; do
		if [ $TILE ]; then
			TILE=${TILE},${L}
		else
			TILE=$L
		fi
		echo $TILE
	done
fi

#
# download MODIS Images of target year.
#
SPAN_FROM=${YEAR}-${DATE_FROM}
SPAN_TO=${YEAR}-${DATE_TO}

echo "PRODUCT = ${PRODUCT}"
echo "SPAN FROM = ${SPAN_FROM}"
echo "SPAN TO = ${SPAN_TO}"
echo "SAVE PATH = ${SAVEPATH}"

python ${MODIS_DOWNLOAD_PY} -D 46 -t $TILE -s MOTA -p $PRODUCT -f $SPAN_TO -e $SPAN_FROM $SAVEPATH
if [ $? -ne 0 ]; then
	exit 1
fi


#
# download MODIS Images of previous year.
#
SPAN_FROM=`expr ${YEAR} - 1`-${DATE_FROM}
SPAN_TO=`expr ${YEAR} - 1`-${DATE_TO}
python ${MODIS_DOWNLOAD_PY} -D 46 -t $TILE -s MOTA -p $PRODUCT -f $SPAN_TO -e $SPAN_FROM $SAVEPATH
if [ $? -ne 0 ]; then
	exit 1
fi


#
# download MODIS Images of next year.
#
SPAN_FROM=`expr ${YEAR} + 1`-${DATE_FROM}
SPAN_TO=`expr ${YEAR} + 1`-${DATE_TO}
python ${MODIS_DOWNLOAD_PY} -D 46 -t $TILE -s MOTA -p $PRODUCT -f $SPAN_TO -e $SPAN_FROM $SAVEPATH
