#!/bin/bash

if [ -z "$GISBASE" ] ; then
    echo "ERROR: You must be in GRASS GIS to run this program." 1>&2
    exit 1
fi

if [ -z "$R_BIN" ]; then
	ENVFILE=`dirname $0`/modis_setenv.txt
	echo $ENVFILE
	if [ ! -e $ENVFILE ]; then
		g.message -e "modis_setenv.txt was not found. You must put modis_setenv.txt in the same directory as this script."
		exit 1
	fi
	source $ENVFILE
fi

LIST=`g.mlist type=rast pattern="agg_*" exclude="expand_*"`

for I in $LIST; do

	PREFIX=`echo $I | cut -d '_' -f 2`
	NEWNAME="expand_${I}"

	if [ $PREFIX = "ndviave" ] || [ $PREFIX = "ndsimin" ]; then

		echo $NEWNAME
		r.mapcalc "${NEWNAME}=(${I}+1)*5000"
		if [ $? -ne 0 ]; then
			exit 1
		fi

	elif [ $PREFIX = "siave" ]; then

		echo $NEWNAME
		r.mapcalc "${NEWNAME}=${I}*10000"
		if [ $? -ne 0 ]; then
			exit 1
		fi

	else
		continue
	fi

done

#
# expand NDVI and NDSI layers.
#
LIST=`g.mlist type=rast pattern="*_nd*i" exclude="expand_*"`

for I in $LIST; do

	NEWNAME="expand_${I}"
	echo $NEWNAME
	r.mapcalc "$NEWNAME = (${I}+1)*5000"
	if [ $? -ne 0 ]; then
		exit 1
	fi

done

#
# expand SI layers.
#
LIST=`g.mlist type=rast pattern="*_si" exclude="expand_*"`

for I in $LIST; do

	NEWNAME="expand_${I}"
	echo $NEWNAME
	r.mapcalc "$NEWNAME = ${I} * 10000"
	if [ $? -ne 0 ]; then
		exit 1
	fi

done
