#!/bin/bash

if [ $# != 4 ]; then
	echo "modis_extract_dn usage: [training raster] [class raster] [output report text(.csv)] [num of training points]"
	exit 1
fi

if [ -z "$GISBASE" ] ; then
    echo "ERROR: You must be in GRASS GIS to run this program." 1>&2
    exit 1
fi

if [ -z "$R_BIN" ]; then
	ENVFILE=`dirname $0`/modis_setenv.txt
	echo $ENVFILE
	if [ ! -e $ENVFILE ]; then
		g.message -e "modis_setenv.txt was not found. You must put modis_setenv.txt in the same directory as this script."
		exit 1
	fi
	source $ENVFILE
fi

TRAINING=$1
CLASSIFIED_RASTER=$2
OUTPUT=$3
NUM=$4

eval `g.findfile element=CELL file=$TRAINING`
if [ ! $file ]; then
	g.message -e "Training raster layer [${TRAINING}] was not found."
	exit 1
fi

eval `g.findfile element=CELL file=$TRAINING`
if [ ! $file ]; then
	g.message -e "CLASS raster layer [${CLASSIFIED_RASTER}] was not found."
	exit 1
fi

VTEMP=`basename ${OUTPUT} ".csv"`
if [ $VTEMP = "`basename ${OUTPUT}`" ]; then
	g.message -e "[$OUTPUT]; output filename must have .csv extension."
	exit 1
fi

if [ -e $OUTPUT ]; then

	rm -f $OUTPUT
fi

#r.mask input=$TRAINING
r.random --o input=$TRAINING vector_output=${VTEMP} n=${NUM}
if [ $? -ne 0 ]; then
	g.message -e "error occured in r.random, exit"
	exit 1
fi

v.db.addcol map=${VTEMP} column="class INTEGER"
v.what.rast vector=${VTEMP} raster=${CLASSIFIED_RASTER} column="class"

I=1
for R in `g.mlist type=rast pattern="interp_*_band*" 2> /dev/null`; do

	echo $R
	v.db.addcol map=${VTEMP} column="c${I} DOUBLE PRECISION"
	if [ $? -ne 0 ]; then
		exit 1
	fi
	v.what.rast vector=${VTEMP} raster=$R column="c$I"
	v.edit map=$VTEMP tool=delete where="C${I} is NULL"
	if [ $? -ne 0 ]; then
		exit 1
	fi
	((I++))

done

db.out.ogr input=${VTEMP} dsn=$OUTPUT format=CSV
g.remove vect=${VTEMP}

#if [ `g.mlist pattern="MASK_"` ]; then
#	g.rename rast="MASK_,MASK"
#fi
