#!/bin/bash

if [ $# != 1 ]; then
	echo "modis_fillnull.sh usage: [target year]"
	exit 1
fi

if [ -z "$GISBASE" ] ; then
    echo "ERROR: You must be in GRASS GIS to run this program." 1>&2
    exit 1
fi

if [ -z "$R_BIN" ]; then
	ENVFILE=`dirname $0`/modis_setenv.txt
	echo $ENVFILE
	if [ ! -e $ENVFILE ]; then
		g.message -e "modis_setenv.txt was not found. You must put modis_setenv.txt in the same directory as this script."
		exit 1
	fi
	source $ENVFILE
fi

YEAR=$1

LIST=`g.mlist type=rast pattern="interp_${PRODUCT_NAME}.A${YEAR}*"`
if [ `echo $LIST | wc -w` -eq 0 ]; then
	g.message -e "Raster layer of target year [${YEAR}] was not found."
	exit 1
fi

mkdir temp
cd temp

for B in $LIST; do
#for B in `g.mlist type=rast pattern="interp_MCD43B4.A2008145_band4"`; do

#
# export current image.
#

	echo "-- $B"
	r.out.gdal input=${B} output=${B}.tif type=Float32 
	if [ $? -ne 0 ]; then
		exit 1
	fi
	rm -f *.xml

#
# execute gdal_fillnodata command.
#

	gdal_fillnodata.py -of GTiff ${B}.tif fill_${B}.tif
	if [ $? -ne 0 ]; then
		exit 1
	fi

#
# import artifact of gdal_fillnodata.
# replace interpolated raster maps to r.fillnull output raster.
#

	g.rename rast=${B},old_${B}
	r.in.gdal --overwrite input=fill_${B}.tif output="temp"
	if [ $? -ne 0 ]; then
		exit 1
	fi
	r.mapcalc "${B}=if(temp<0,0,temp)"
	if [ $? -ne 0 ]; then
		exit 1
	fi

done

g.remove rast=temp

cd ..
rm -r -f temp
