#!/bin/bash

if [ $# != 2 ]; then
	echo "modis_import_See5 usage: [input file(.tree)] [output layer name]"
	exit 1
fi

if [ -z "$GISBASE" ] ; then
    echo "ERROR: You must be in GRASS GIS to run this program." 1>&2
    exit 1
fi

if [ -z "$R_BIN" ]; then
	ENVFILE=`dirname $0`/modis_setenv.txt
	echo $ENVFILE
	if [ ! -e $ENVFILE ]; then
		g.message -e "modis_setenv.txt was not found. You must put modis_setenv.txt in the same directory as this script."
		exit 1
	fi
	source $ENVFILE
fi

OUTPUT_LAYER=$2
AWKFILE=`dirname $0`/parsetree.awk
if [ ! -e $AWKFILE ]; then
	g.message -e "parsetree.awk was not found. You must put parsetree.awk in the same directory as this script."
	exit 1
fi

EXPTEXT=`awk -f ${AWKFILE} $1`

FIRST=0
for E in ${EXPTEXT}; do

	r.mapcalc temp_class=${E}
	if [ $? -ne 0 ]; then
		exit 1
	fi
	if [ $FIRST -eq 0 ]; then
		g.rename temp_class,$OUTPUT_LAYER
		FIRST=1
	else
		g.rename $OUTPUT_LAYER,see5class_old
		r.patch --o input=see5class_old,temp_class output=$OUTPUT_LAYER
		g.remove -f rast=see5class_old,temp_class
	fi
done

