#!/bin/bash

if [ -z "$GISBASE" ] ; then
    echo "ERROR: You must be in GRASS GIS to run this program." 1>&2
    exit 1
fi

if [ $# != 2 ]; then
	echo "modis_import_kml usage: [imput file] [output layer name]"
	exit 1
fi

if [ -z "$R_BIN" ]; then
	ENVFILE=`dirname $0`/modis_setenv.txt
	echo $ENVFILE
	if [ ! -e $ENVFILE ]; then
		g.message -e "modis_setenv.txt was not found. You must put modis_setenv.txt in the same directory as this script."
		exit 1
	fi
	source $ENVFILE
fi

INPUT=$1
if [ ! -e $1 ]; then
	g.message -e "file not found : $INPUT"
	exit 1
fi

#
# convert kml to shp.
# field is also converted "Name" => "Class", STRING => INTEGER
#
SHPNAME=`python << EOF

import sys, os
import ogr, osr
import shutil

ogr.RegisterAll()

srcDs = ogr.Open("$1")
if srcDs is None:
	print "file not fount : " + "$1"
	sys.exit(1)

newfname = os.path.splitext("$1")[0]
if os.path.exists(newfname):
	shutil.rmtree(newfname)
drv = ogr.GetDriverByName("ESRI Shapefile")
dstDs = drv.CreateDataSource(newfname)
if dstDs is None:
	print "Creation of output file failed."
	sys.exit(1)

srcLayer = srcDs.GetLayer()
srs = srcLayer.GetSpatialRef()
dstLname = os.path.splitext(os.path.basename("$1"))[0]
dstLayer = dstDs.CreateLayer(dstLname, srs, ogr.wkbPolygon)

dstDefn = ogr.FieldDefn("Class", ogr.OFTInteger)
dstDefn.SetWidth(3)
dstLayer.CreateField(dstDefn)

srcFeature = srcLayer.GetNextFeature()
while srcFeature is not None:
	cls = srcFeature.GetFieldAsString(0)
	geom = srcFeature.GetGeometryRef()

	dstFeature = ogr.Feature(feature_def=dstLayer.GetLayerDefn())
	dstFeature.SetField("Class", int(cls))
	dstFeature.SetGeometry(geom)
	dstLayer.CreateFeature(dstFeature)

	dstFeature.Destroy()

	srcFeature = srcLayer.GetNextFeature()

print newfname

srcDs.Destroy()
dstDs.Destroy()
EOF
`

#
# import SHP to GRASS.
#
v.in.ogr dsn=$SHPNAME output=$2 

rm -r -f $SHPNAME
