#!/bin/bash

if [ $# != 1 ] && [ $# != 3 ]; then
	echo "modis_import_result usage: [input file] [[see5 class layer] [class no](optional)]"
	exit 1
fi

if [ -z "$GISBASE" ] ; then
    echo "ERROR: You must be in GRASS GIS to run this program." 1>&2
    exit 1
fi

if [ -z "$R_BIN" ]; then
	ENVFILE=`dirname $0`/modis_setenv.txt
	echo $ENVFILE
	if [ ! -e $ENVFILE ]; then
		g.message -e "modis_setenv.txt was not found. You must put modis_setenv.txt in the same directory as this script."
		exit 1
	fi
	source $ENVFILE
fi

if [ $# == 3 ]; then
	SEE5LAYER=$2
	CLASSNO=$3

	eval `g.findfile element=cell file=$SEE5LAYER`
	if [ ! "$file" ]; then
		g.message -e "See5 layer does not exist [ $SEE5LAYER ]"
		exit 1
	fi

	eval `g.findfile element=cell file=MASK`
	if [ "$file" ]; then
		g.rename rast="MASK","MASK_"
	fi

	r.mask input="$SEE5LAYER" maskcats="$CLASSNO"
fi

AWKFILE=`dirname $0`/parsemodel.awk
if [ ! -e $AWKFILE ]; then
	g.message -e "parsemodel.awk was not found. You must put parsemodel.awk in the same directory as this script."
	exit 1
fi

EXPTEXT=`awk -f ${AWKFILE} $1`

RESNUM=0
for E in ${EXPTEXT}; do

	r.mapcalc res_${CLASSNO}${RESNUM}=${E}
	if [ $? -ne 0 ]; then
		exit 1
	fi
	RESNUM=`expr ${RESNUM} + 1`

done

#
# restore MASK layer
#

r.mask -r
eval `g.findfile element=cell file=MASK_`
if [ "$file" ]; then
	g.rename rast="MASK_","MASK"
fi
