
################################ functions ########################################

depend <- function( Sim, per )
{
	r.valid=TRUE
	ndvi <- c()
	
	ndvi <- (Sim[,2]-Sim[,1])/(Sim[,2]+Sim[,1])
	
	sndvi <- sort( ndvi )
	ndvinum <- order( ndvi )

	if ( length(sndvi) < 3 )
	{
		 r.valid=FALSE
	}
	
	r.ndviave <- ( ndvi[1]+ndvi[2]+ndvi[3] ) / 3.0

	r.band <- (Sim[ndvinum[1],]+Sim[ndvinum[2],]+Sim[ndvinum[3],]) / 3.0

	ndsi <- c( 
		as.double(Sim[ndvinum[1],6]-Sim[ndvinum[1],2])/as.double(Sim[ndvinum[1],6]+Sim[ndvinum[1],2]),
		as.double(Sim[ndvinum[2],6]-Sim[ndvinum[2],2])/as.double(Sim[ndvinum[2],6]+Sim[ndvinum[2],2]),
		as.double(Sim[ndvinum[3],6]-Sim[ndvinum[3],2])/as.double(Sim[ndvinum[3],6]+Sim[ndvinum[3],2]) )
	
	r.ndsimin <- min( ndsi )
	
	si <- c(
		( (1.0-Sim[ndvinum[1],1]/(10.0^4))*(1.0-Sim[ndvinum[1],3]/(10.0^4))*(1.0-Sim[ndvinum[1],4]/(10.0^4)) ) ^ (1/3),
		( (1.0-Sim[ndvinum[2],1]/(10.0^4))*(1.0-Sim[ndvinum[2],3]/(10.0^4))*(1.0-Sim[ndvinum[2],4]/(10.0^4)) ) ^ (1/3),
		( (1.0-Sim[ndvinum[3],1]/(10.0^4))*(1.0-Sim[ndvinum[3],3]/(10.0^4))*(1.0-Sim[ndvinum[3],4]/(10.0^4)) ) ^ (1/3) )
		
	r.siave <- (si[1] + si[2] + si[3]) / 3.0

	list( ndviave=r.ndviave, band=r.band, ndsimin=r.ndsimin, siave=r.siave, valid=r.valid )
}

writeResult <- function( fname, count, SimPTC, ndviave, band, ndsimin, siave )
{
	if ( is.na( ndviave ) || is.element( NA,band ) || is.na( ndsimin ) || is.na( siave ) ) return( NULL )

	line <- sprintf( "%6f,%4f,%8.4f,%8.2f,%8.2f,%8.2f,%8.2f,%8.2f,%8.2f,%8.2f,%8.4f,%8.4f",
		count, SimPTC, ndviave, band[1], band[2], band[3], band[4], band[5], band[6], band[7], ndsimin, siave )
	write( line, fname, append=TRUE )
}



###################################################################################

args <- commandArgs(trailingOnly = TRUE)
fname <- args[2]
tree <- as.integer( unlist(strsplit(args[3], split=",")) )
ub <- as.integer( unlist(strsplit(args[4], split=",")) )

rawdata <- read.csv( paste("./", args[1], sep=""), header=TRUE )

# sort data by class
rawmat <- as.matrix(rawdata)
mat <- matrix( ncol = dim(rawmat)[2] )
for ( t in tree )
{
	mat <- rbind( mat, matrix( rawmat[rawmat[,3]==t], ncol=dim(rawmat)[2] ) )
	rawmat[rawmat[,3]==t] <- -1
}
for ( u in ub )
{
	mat <- rbind( mat, matrix( rawmat[rawmat[,3]==u], ncol=dim(rawmat)[2] ) )
	rawmat[rawmat[,3]==u] <- -1
}
mat <- rbind( mat, matrix( rawmat[rawmat[,3]!=-1], ncol=dim(rawmat)[2] ) )
mat <- mat[,c(-1,-3)]
mat <- mat[-1,]
print( mat )
rm( rawmat )
rm( rawdata )

# Number of periods
num <- dim(mat)[1]
per <- (dim(mat)[2]-1)/7

print( num )
print( per )
print( tree )
print( ub )

# number of training sites ?
PTC <- mat[,1]
R <- mat[,2:(dim(mat)[2])]
dim(R) <- c(num,7,per)


# Calclating Simulation Training Data
count <- 0
CC <- c( 0, 0, 0, 0, 0, 0, 0 )

for ( i in 0:10 )
{
	for ( j in 0:(10-i) )
	{
		k <- 10 - i - j
		n <- 0
		if ( i != 0 && j != 0 && k != 0 )
		{
			print( "pattern 1" )
			cat( "i=")
			cat( i )
			cat( " j=" )
			cat( j )
			cat( " k=" )
			cat( k )
			for ( s in 1:tree )
			{
				for ( u in (tree+1):(tree+ub) )
				{
					for ( v in (tree+ub+1):num )
					{
						count <- count + 1
						CC[1] <- CC[1] + 1
						Sim <- t( (i*R[s,,]+j*R[u,,]+k*R[v,,])/10.0 )
						SimPTC <- as.integer( floor((i*PTC[s] + j*PTC[u] + k*PTC[v])/10.0 + 0.5) )
						result <- depend( Sim, per )
						if ( result$valid == FALSE )
						{
							n <- n+1
							next
						}
						# write : count, SimPTC, ndviave, band[1-7], ndsimin, siave
						writeResult( fname, count, SimPTC, result$ndviave, result$band, result$ndsimin, result$siave )
						n <- n+1
					}
				}
			}
			print( n )
		}
		else if ( i == 0 && j == 0 )
		{
			print( "pattern 2" )
			cat( "i=")
			cat( i )
			cat( " j=" )
			cat( j )
			cat( " k=" )
			cat( k )
			for ( v in (tree+ub+1):num )
			{
				count <- count + 1
				CC[5] <- CC[5] + 1
				Sim <- t( R[v,,] )
				SimPTC <- PTC[v]
				result <- depend( Sim, per )
				if ( result$valid == FALSE )
				{
					n <- n+1
					next
				}
				# write : count, SimPTC, ndviave, band[1-7], ndsimin, siave
				writeResult( fname, count, SimPTC, result$ndviave, result$band, result$ndsimin, result$siave )
				n <- n+1
			}
			print( n )
		}
		else if ( i == 0 && k == 0 )
		{
			print( "pattern 3" )
			cat( "i=")
			cat( i )
			cat( " j=" )
			cat( j )
			cat( " k=" )
			cat( k )
			for ( u in (tree+1):(tree+ub) )
			{
				count <- count + 1
				CC[6] <- CC[6] + 1
				Sim <- t( R[u,,] )
				SimPTC <- PTC[u]
				result <- depend( Sim, per )
				if ( result$valid == FALSE )
				{
					n <- n+1
					next
				}
				# write : count, SimPTC, ndviave, band[1-7], ndsimin, siave
				writeResult( fname, count, SimPTC, result$ndviave, result$band, result$ndsimin, result$siave )
				n <- n+1
			}
			print( n )
		}
		else if ( j == 0 && k == 0 )
		{
			print( "pattern 4" )
			cat( "i=")
			cat( i )
			cat( " j=" )
			cat( j )
			cat( " k=" )
			cat( k )
			for ( s in 1:tree )
			{
				count <- count + 1
				CC[7] <- CC[7] + 1
				Sim <- t( R[s,,] )
				SimPTC <- PTC[s]
				result <- depend( Sim, per )
				if ( result$valid == FALSE )
				{
					n <- n+1
					next
				}
				# write : count, SimPTC, ndviave, band[1-7], ndsimin, siave
				writeResult( fname, count, SimPTC, result$ndviave, result$band, result$ndsimin, result$siave )
				n <- n+1
			}
			print( n )
		}
		else if ( i == 0 )
		{
			print( "pattern 5" )
			cat( "i=")
			cat( i )
			cat( " j=" )
			cat( j )
			cat( " k=" )
			cat( k )
			for ( u in (tree+1):(tree+ub) )
			{
				for ( v in (tree+ub+1):num )
				{
					count <- count + 1
					CC[2] <- CC[2] + 1
					Sim <- t( c(R[u,,], R[v,,])*c(j,k)*0.1 )
					Sim <- t( (j*R[u,,]+k*R[v,,])/10.0 )
					SimPTC <- as.integer( floor((j*PTC[u] + k*PTC[v])/10.0 + 0.5) )
					result <- depend( Sim, per )
					if ( result$valid == FALSE )
					{
						n <- n+1
						next
					}
					# write : count, SimPTC, ndviave, band[1-7], ndsimin, siave
					writeResult( fname, count, SimPTC, result$ndviave, result$band, result$ndsimin, result$siave )
					n <- n+1
				}
			}
			print( n )
		}
		else if ( j == 0 )
		{
			print( "pattern 6" )
			cat( "i=")
			cat( i )
			cat( " j=" )
			cat( j )
			cat( " k=" )
			cat( k )
			for ( s in 1:tree )
			{
				for ( v in (tree+ub+1):num )
				{
					count <- count + 1
					CC[3] <- CC[3] + 1
					Sim <- t( (i*R[s,,]+k*R[v,,])/10.0 )
					SimPTC <- as.integer( floor((i*PTC[u] + k*PTC[v])/10.0 + 0.5) )
					result <- depend( Sim, per )
					if ( result$valid == FALSE )
					{
						n <- n+1
						next
					}
					# write : count, SimPTC, ndviave, band[1-7], ndsimin, siave
					writeResult( fname, count, SimPTC, result$ndviave, result$band, result$ndsimin, result$siave )
					n <- n+1
				}
			}
			print( n )
		}
		else if ( k == 0 )
		{
			print( "pattern 7" )
			cat( "i=")
			cat( i )
			cat( " j=" )
			cat( j )
			cat( " k=" )
			cat( k )
			for ( s in 1:tree )
			{
				for ( u in (tree+1):(tree+ub) )
				{
					count <- count + 1
					CC[4] <- CC[4] + 1
					Sim <- t( (i*R[s,,]+j*R[u,,])/10.0 )
					SimPTC <- as.integer( floor((i*PTC[s] + j*PTC[u])/10.0 + 0.5) )
					result <- depend( Sim, per )
					if ( result$valid == FALSE )
					{
						n <- n+1
						next
					}
					# write : count, SimPTC, ndviave, band[1-7], ndsimin, siave
					writeResult( fname, count, SimPTC, result$ndviave, result$band, result$ndsimin, result$siave )
					n <- n+1
				}
			}
			print( n )
		}
	}
	# write "finished"
	# format(I6,', ',I3,', ',F7.4,', ',7(F7.2,', '),F7.4,', ',F7.4)
}
