#!/bin/bash

if [ -z "$R_BIN" ]; then
	ENVFILE=`dirname $0`/modis_setenv.txt
	echo $ENVFILE
	if [ ! -e $ENVFILE ]; then
		echo "ERROR: modis_setenv.txt was not found. You must put modis_setenv.txt in the same directory as this script."
		exit 1
	fi
	source $ENVFILE
fi

if [ $# != 0 ] && [ $# != 4 ]; then
	echo "viirs_merge.sh usage: [[xmin] [ymin] [xmax] [ymax] (optional)]"
	echo "xmin,ymin,xmax,ymax are the extent of target SRS."
	echo "if not specified, extent of the warped image is calculated automatically."
fi

if [ $# == 4 ]; then
	OPT_TE="-ul_lr $@"
fi

#
# make directory and translate subsets of hdf.
#
for i in `ls *.h5`; do

	DATALIST=`gdalinfo $i | grep "NAME=" | grep "Radiance" | cut -d "=" -f 2`

	for L in $DATALIST; do

		OUTPUTNAME=`echo $L | cut -d "=" -f 2 | cut -d "_" -f 3-6,10 | sed 's/Data\/VIIRS-//' | cut -d "-" -f 1 | sed 's/_I/_band/'`
		gdalwarp -of "GTiff" -r bilinear -t_srs EPSG:4326 -dstnodata 65535 ${L} viirs_${OUTPUTNAME}.tif
		if [ $? -ne 0 ]; then
			exit 1
		fi

	done

done
